@@ -513,7 +513,7 @@ gint read_config(AppletConfig * config) {
                                                    GCONF_KEY_WEATHER_UPDATE_INTERVAL,
                                                    NULL);
     if (config->update_interval < 0 || config->update_interval > 24 * 60)       /* No more than 24 hours */
-        config->update_interval = 0;
+        config->update_interval = 60;
     remove_periodic_event();    /* delete event from list */
     add_periodic_event(time(NULL));     /* add new event */
 
@@ -1168,10 +1168,8 @@ void check_current_station_id(void) {
                                                                                     &iter);
     while(valid){
        gtk_tree_model_get(GTK_TREE_MODEL(app->user_stations_list), &iter,
-                                        0, &station_name,
                                         1, &station_code,
-                                        2, &is_gps,
-                                        3, &station_source, -1);
+                                        -1);
         if(!strcmp(station_code, app->config->current_station_id)){
             valid = FALSE;
             equals = TRUE;
@@ -1180,6 +1178,8 @@ void check_current_station_id(void) {
             valid = gtk_tree_model_iter_next(GTK_TREE_MODEL(app->user_stations_list), &iter);
             equals = FALSE;
         }
+        if(station_code)
+            g_free(station_code);
     }
 
     if(!equals){
