@@ -41,20 +41,7 @@
     #include <hildon-widgets/hildon-controlbar.h>
 #endif
 /*******************************************************************************/
-struct lists_struct{
-    GtkWidget		*countries;
-    GtkListStore	*countries_list;
-    GtkWidget		*states;
-    GtkListStore	*regions_list;
-    GtkWidget		*stations;
-    GtkListStore	*stations_list;
-    GtkListStore	*sources_list;
-    sqlite3		*database;
-    gboolean		database_invalid;
-};
-/*******************************************************************************/
 extern gboolean		not_event;
-extern WeatherSource	weather_sources[];
 /*******************************************************************************/
 void weather_window_settings(GtkWidget *widget, gpointer user_data);
 void station_list_view_select_handler(GtkTreeView *tree_view,
@@ -67,6 +54,8 @@ gboolean process_update_tab(GtkWidget *vbox);
 #ifdef OS2008
 gboolean process_sensor_tab(GtkWidget *vbox);
 #endif
+GtkWidget *create_layouts_line(GtkWidget *window, gint icon_size, gint mode);
+GtkWidget *create_iconsets_line(GtkWidget *window, gint icon_size, gint mode);
 gboolean process_alert_tab(GtkWidget *vbox);
 void changed_country_handler(GtkWidget *widget, gpointer user_data);
 void changed_state_handler(GtkWidget *widget, gpointer user_data);
@@ -83,8 +72,9 @@ void up_key_handler(GtkButton *button, gpointer list);
 void down_key_handler(GtkButton *button, gpointer list);
 void new_station_handler(GtkButton *button, gpointer user_data);
 void delete_station_handler(GtkButton *button, gpointer user_data);
-void add_station_to_user_list(gchar *weather_station_id,gchar *weather_station_name,
-				gboolean is_gps, gchar *source);
+GtkTreeIter add_station_to_user_list(gchar *weather_station_name, gchar *weather_station_id,
+				gboolean is_gps, gchar *source, gint position);
+void delete_station_from_user_list(gchar *station_selected, gpointer user_data);
 void highlight_current_station(GtkTreeView *tree_view);
 int lookup_and_select_station(gchar *db_path, gchar *station_name, Station *result);
 gboolean switch_cb(GtkNotebook * nb, gpointer nb_page, gint page, gpointer data);
@@ -115,34 +105,4 @@ GtkWidget* create_update_tab(GtkWidget *window);
 GtkWidget* create_test_tab(GtkWidget *window);
 void font_changed_handler(GtkFontButton *widget, gpointer user_data);
 /*******************************************************************************/
-extern void redraw_home_window(gboolean first_start);
-extern void remove_periodic_event(void);
-extern void weather_initialize_dbus(void);
-extern time_t next_update(void);
-extern void print_list(char *buff, size_t buff_size);
-extern void config_save(AppletConfig *config);
-extern void set_background_color(GtkWidget *widget, GdkColor *bgc);
-extern void add_periodic_event(time_t last_update);
-extern void remove_periodic_event(void);
-extern void popup_window_destroy(void);
-extern void add_gps_event(guint interval);
-extern gboolean change_station_select(GtkWidget *widget, gpointer user_data);
-extern gboolean switch_timer_handler(gpointer data);
-extern void help_activated_handler(GtkWidget *window, gchar *help_id);
-extern void update_weather(gboolean show_update_window);
-extern GtkWidget* lookup_widget(GtkWidget *widget, const gchar *widget_name);
-extern void weather_window_popup(GtkWidget *widget, GdkEvent *event, gpointer user_data);
-extern GtkWidget* create_tree_view(GtkListStore* list);
-#if defined(OS2008) || defined(DEBUGTEMP) || defined(OS2009) || defined(NONMAEMO)
-extern GtkWidget* create_sensor_page(GtkWidget *config_window);
-extern void read_sensor(gint need_redraw);
-extern guint get_time_from_index(guint index);
-#endif
-extern GtkWidget* create_button_with_image(const char *path, const char *image_name,
-			int image_size, gboolean with_border, gboolean toggled);
-extern GtkWidget* create_scrolled_window_with_text(const char* text,
-					    GtkJustification justification);
-extern guint get_index_from_time(guint time);
-extern void update_icons_set_base(const char *icon_set_name);
-/*******************************************************************************/
 #endif
