@@ -74,7 +74,6 @@ weather_simple_window_popup(GtkWidget *widget, gpointer user_data){
     GtkWidget       *window = NULL,
                     *view = NULL,
                     *main_vbox = NULL;
-//    gboolean        temp = FALSE;
 #if defined OS2009
     HildonAppMenu   *menu = NULL;
 #endif
@@ -90,15 +89,7 @@ weather_simple_window_popup(GtkWidget *widget, gpointer user_data){
     gtk_window_set_title(GTK_WINDOW(window), _("Forecast"));
 
 //    gtk_window_fullscreen (GTK_WINDOW (window));
-/*
-    while(!temp){
-        temp = get_data_from_url("www.bash.org.ru", "temp");
-        if(temp)
-    	    fprintf(stderr, "\nYES \n");
-    	else
-    	    fprintf(stderr, "\nNO \n");
-    }
-*/
+
     gtk_container_add(GTK_CONTAINER(window), create_mainbox_for_forecast_window(window, user_data));
     gtk_widget_show(window);
 
@@ -115,7 +106,6 @@ weather_simple_window_popup(GtkWidget *widget, gpointer user_data){
                         G_CALLBACK(destroy_popup_window), GINT_TO_POINTER(1));
     g_signal_connect((gpointer)app->popup_window, "delete_event",
                         G_CALLBACK(destroy_popup_window), GINT_TO_POINTER(1));
-
 }
 /*******************************************************************************/
 gchar*
@@ -176,28 +166,7 @@ get_next_station_name(const gchar *current_station_name, GtkListStore *user_stat
             }
         }
     }
-/*
-    while(valid){
-        gtk_tree_model_get(GTK_TREE_MODEL(app->user_stations_list),
-                            &iter, NAME_COLUMN, &station_name, -1);
-        if(ready)
-            return station_name;
-        else{
-            if((current_station_name) && (station_name) &&
-                  !strcmp(current_station_name, station_name))
-                ready = TRUE;
-            g_free(station_name);
-            gtk_tree_path_next(path);
-
-            valid = gtk_tree_model_get_iter(GTK_TREE_MODEL(app->user_stations_list),
-                                        &iter, path);
-            if(!valid)
-                valid = gtk_tree_model_get_iter_first(GTK_TREE_MODEL(app->user_stations_list),
-                                        &iter);
-        }
-    }
-*/
-    gtk_tree_path_free(path);
+   gtk_tree_path_free(path);
     return station_name;
 #ifdef DEBUGFUNCTIONCALL
     END_FUNCTION;
@@ -453,10 +422,8 @@ create_weather_collapsed_view(GtkWidget *vbox, gint day_number){
             set_font(line_text, NULL, 12);
             gtk_box_pack_start(GTK_BOX(line_hbox), line_text, FALSE, TRUE, 10);
 
-            if(day_number == i){
-                fprintf(stderr,"This day must be activity!!! %i\n",i);
+            if(day_number == i)
                 g_object_set_data(G_OBJECT(scrolled_window), "selected_widget", (gpointer)separator);
-            }
             /* next day */
             days = g_slist_next(days);
             i++;
@@ -487,6 +454,7 @@ create_weather_expanded_view(GtkWidget *vbox, gint day_number){
                         *main_vbox = NULL,
                         *line = NULL,
                         *separator = NULL,
+                        *previos_separator = NULL,
                         *vscrollbar = NULL;
     gchar               *day_name = NULL;
     time_t              current_time = 0,
@@ -508,7 +476,6 @@ create_weather_expanded_view(GtkWidget *vbox, gint day_number){
                                             GTK_SHADOW_NONE);
     gtk_scrolled_window_set_policy(GTK_SCROLLED_WINDOW(scrolled_window),
                                        GTK_POLICY_NEVER, GTK_POLICY_AUTOMATIC);
-    vscrollbar = gtk_scrolled_window_get_vscrollbar(scrolled_window);
     hildon_helper_set_thumb_scrollbar(scrolled_window, TRUE);
     gtk_scrolled_window_add_with_viewport(scrolled_window, main_vbox);
 #endif
@@ -559,7 +526,12 @@ create_weather_expanded_view(GtkWidget *vbox, gint day_number){
             line = gtk_button_new();
             gtk_button_set_focus_on_click(GTK_BUTTON(line), FALSE);
             gtk_button_set_relief(GTK_BUTTON(line), GTK_RELIEF_NONE);
-            g_signal_connect(G_OBJECT(line), "clicked",
+            if (i == 0)
+                g_signal_connect(G_OBJECT(line), "clicked",
+                                            G_CALLBACK(show_detailes_of_current_day_button_handler),
+                                                                             GINT_TO_POINTER(i));
+            else
+                g_signal_connect(G_OBJECT(line), "clicked",
                                 G_CALLBACK(show_collapsed_day_button_handler),
                                  GINT_TO_POINTER(i));
 
@@ -570,12 +542,13 @@ create_weather_expanded_view(GtkWidget *vbox, gint day_number){
         gtk_container_add(GTK_CONTAINER(line), day_widget);
         gtk_box_pack_start(GTK_BOX(main_vbox), line, TRUE, TRUE, 0);
         gtk_box_pack_start(GTK_BOX(main_vbox), separator = gtk_hseparator_new(), FALSE, TRUE, 0);
-
+        if(day_number == i && !(i == 0 && current_widget && current))
+            previos_separator = separator;
         /* If activited day and not current weather */
-        if(day_number == i && !(i == 0 && current_widget && current)){
-            fprintf(stderr,"This day must be activity!!! %i\n",i);
-            g_object_set_data(G_OBJECT(scrolled_window), "selected_widget", (gpointer)separator);
-        }
+        if(day_number + 1 == i && !(i == 0 && current_widget && current))
+            g_object_set_data(G_OBJECT(scrolled_window), "selected_widget", (gpointer)previos_separator);
+        if(day_number == Max_count_weather_day - 1 && i == Max_count_weather_day - 1)
+            g_object_set_data(G_OBJECT(scrolled_window), "selected_widget", (gpointer)line);
         tmp = g_slist_next(tmp);
         i++;
     }
@@ -661,7 +634,6 @@ create_weather_for_two_hours_collapsed_view(GtkWidget *vbox, gint day_number){
 #ifdef DEBUGFUNCTIONCALL
     START_FUNCTION;
 #endif
-
     main_vbox = gtk_vbox_new(FALSE, 5);
     /* scrolled window */
 #if defined OS2009
@@ -703,7 +675,9 @@ create_weather_for_two_hours_collapsed_view(GtkWidget *vbox, gint day_number){
 
             /*Prepare date from xml file*/
 
-            snprintf(hour_last_update + strlen(hour_last_update), "%s",
+            snprintf(hour_last_update + strlen(hour_last_update),
+                    sizeof(hour_last_update) - strlen(hour_last_update) - 1,
+                    "%s",
                     (char*)g_hash_table_lookup(g_hash_table_lookup(app->station_data, 
                                                "detail"), "last_update"));
             date_size = strcspn(hour_last_update, " ");
@@ -730,8 +704,8 @@ create_weather_for_two_hours_collapsed_view(GtkWidget *vbox, gint day_number){
             if((difference < 0 && difference > -60*60) || difference >= 0 ||
                                       (prev_difference > 0 &&  difference<0)) {
 
-               // fprintf(stderr, "\nHOURS %d\n", hours_time);
-
+//                fprintf(stderr, "\nHOURS %d\n", hours_time);
+                flag = TRUE; 
                 line = gtk_event_box_new();
                 icon_text_hbox = gtk_hbox_new(FALSE, 0);
                 *buffer = 0;
@@ -763,14 +737,10 @@ create_weather_for_two_hours_collapsed_view(GtkWidget *vbox, gint day_number){
                 sprintf(tmp + strlen(tmp), "%s", _("Forecast at: "));
                 sprintf(tmp + strlen(tmp), "%s:00\n",
                                 (char*)g_hash_table_lookup(hour_weather, "hours"));
-
-                if(tmp){
-                    snprintf(buffer, sizeof(buffer) - 1, 
+                snprintf(buffer, sizeof(buffer) - 1, 
                                                 "<span weight=\"bold\">%s", tmp);
-                    snprintf(buffer + strlen(buffer), 
+                snprintf(buffer + strlen(buffer), 
                                     sizeof(buffer) - strlen(buffer) - 1,"</span>");
-                }
-
                 *tmp = 0;
                 /* temperature */
                 sprintf(tmp, " %d\302\260",
@@ -846,8 +816,14 @@ create_weather_for_two_hours_collapsed_view(GtkWidget *vbox, gint day_number){
         gtk_widget_destroy(scrolled_window);
         return NULL;
     }
- gtk_widget_show_all(scrolled_window);
- return scrolled_window;
+ if (flag){
+    gtk_widget_show_all(scrolled_window);
+    return scrolled_window;
+ }else{
+    gtk_widget_destroy(scrolled_window);
+    return NULL;
+ }
+
 }
 /*******************************************************************************/
 #if defined OS2009
