@@ -422,7 +422,7 @@ save_station(GtkWidget *window){
     gtk_table_attach((GtkTable*)(g_object_get_data(G_OBJECT(window), "settings_window_table")),
                                 stations_box, 1, 2, 1, 2, (GtkAttachOptions)0,
                                 (GtkAttachOptions)0, 0, 0 );
-
+#ifdef ENABLE_GPS
     /* Run gps daemon */
     if (is_gps && g_strdup(g_object_get_data(G_OBJECT(window), "station_code")) &&
        !strcmp(g_strdup(g_object_get_data(G_OBJECT(window), "station_code"))," ")){
@@ -432,6 +432,7 @@ save_station(GtkWidget *window){
           app->gps_was_started = TRUE;
        }
     }
+#endif
 #ifdef DEBUGFUNCTIONCALL
     END_FUNCTION;
 #endif
@@ -976,7 +977,12 @@ update_save(GtkWidget *window){
         if(!gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(wlan)))
             app->config->update_wlan = FALSE;
     }
-
+    if(app->config->update_interval == 0)
+        remove_periodic_event();
+    else{
+        remove_periodic_event();
+        add_periodic_event(time(NULL));
+    }
 }
 /*******************************************************************************/
 void
@@ -1859,7 +1865,7 @@ weather_simple_window_settings(gpointer user_data){
 
     window = gtk_dialog_new();
     gtk_widget_show(window);
-    gtk_window_set_title(GTK_WINDOW(window), _("Settings"));
+    gtk_window_set_title(GTK_WINDOW(window), _("OMWeather Settings"));
     gtk_window_set_position(GTK_WINDOW(window), GTK_WIN_POS_CENTER);
     gtk_window_set_modal(GTK_WINDOW(window), TRUE);
 
