@@ -59,14 +59,15 @@ GtkListStore *create_items_list(const char *path, const char *filename,
 
     max_bytes = end - start;
     fh = fopen(buff, "rt");
-    if (!fh) {
+    if(!fh){
         fprintf(stderr, "\nCan't read file %s: %s", buff, strerror(errno));
-        items_number && (*items_number = count);
+        if(items_number)
+            *items_number = count;
         list = NULL;
     } else {
         if (!strcmp(filename, LOCATIONSFILE))
             list = gtk_list_store_new(5, G_TYPE_STRING, G_TYPE_STRING,
-					G_TYPE_STRING,
+                                      G_TYPE_STRING,
                                       G_TYPE_DOUBLE, G_TYPE_DOUBLE);
         else
             list =
@@ -77,7 +78,8 @@ GtkListStore *create_items_list(const char *path, const char *filename,
                 fprintf(stderr,
                         "\nCan't seek to the position %ld on %s file: %s\n",
                         start, buff, strerror(errno));
-                items_number && (*items_number = count);
+                if(items_number)
+                    *items_number = count;
                 return NULL;
             }
         while (!feof(fh)) {
@@ -124,10 +126,10 @@ GtkListStore *create_items_list(const char *path, const char *filename,
         }
         fclose(fh);
     }
-    items_number && (*items_number = count);
+    if(items_number)
+        *items_number = count;
     return list;
 }
-
 /*******************************************************************************/
 int parse_country_string(const char *string, Country_item * result) {
     char *delimiter = NULL, *tmp, buffer[32];
@@ -341,9 +343,11 @@ GtkListStore* create_countries_list(sqlite3 *database){
     gint		rc;
     gchar		*errMsg = NULL;
 
+#ifdef DEBUGFUNCTIONCALL
+    START_FUNCTION;
+#endif
     if(!database)
-	return NULL;	/* database doesn't open */
-
+        return NULL;    /* database doesn't open */
     list = gtk_list_store_new(2, G_TYPE_STRING, G_TYPE_INT);
     rc = sqlite3_exec(database, "SELECT * FROM countries ORDER BY name",
 			countries_callback, (void*)list, &errMsg);
@@ -375,7 +379,7 @@ GtkListStore* create_regions_list(sqlite3 *database, int country_id, int *region
                                  G_TYPE_DOUBLE, G_TYPE_DOUBLE);
     data.list = list;
     *sql = 0;
-    if (country_id == 0)
+    if (country_id == 0) /* for GPS */
         snprintf(sql, sizeof(sql) - 1,
                  "SELECT id, name, longititudemax, latitudemax, longititudemin, latitudemin \
                   FROM regions");
@@ -412,47 +416,248 @@ GtkListStore* create_stations_list(sqlite3 *database, int region_id){
 #endif
 
     if(!database || !region_id)
-	return NULL;	/* database doesn't open */
+        return NULL;/* database doesn't open */
 
     list = gtk_list_store_new(4, G_TYPE_STRING, G_TYPE_STRING, G_TYPE_DOUBLE,
-				G_TYPE_DOUBLE);
+        G_TYPE_DOUBLE);
     *sql = 0;
     snprintf(sql, sizeof(sql) - 1,
-		"SELECT name, code, longititude, latitude FROM stations WHERE \
-		region_id = %d ORDER BY name", region_id);
+        "SELECT name, code, longititude, latitude FROM stations WHERE \
+        region_id = %d ORDER BY name", region_id);
     rc = sqlite3_exec(database, sql, stations_callback, (void*)list, &errMsg);
     if(rc != SQLITE_OK){
 #ifndef RELEASE
-	    fprintf(stderr, "\n>>>>%s\n", errMsg);
+        fprintf(stderr, "\n>>>>%s\n", errMsg);
 #endif
-    	sqlite3_free(errMsg);
-	    return NULL;
+        sqlite3_free(errMsg);
+        return NULL;
     }
 #ifdef DEBUGFUNCTIONCALL
     END_FUNCTION;
 #endif
     return list;
 }
+
 /*******************************************************************************/
-GtkListStore* search_station_in_database(sqlite3 *database, char *code_name){
+gint
+get_all_information_callback(void *user_data, int argc, char **argv, char **azColName){
+    int			i;
+    GtkTreeIter		iter;
+    GtkListStore	*list = GTK_LIST_STORE(user_data);
+#ifdef DEBUGFUNCTIONCALL
+    START_FUNCTION;
+#endif
+
+/* add new item for each first element */
+    gtk_list_store_append(list, &iter);
+    for(i = 0; i < argc; i++){
+        if(!strcmp(azColName[i], "cname"))
+            gtk_list_store_set(list, &iter, 0, argv[i], -1);
+        if(!strcmp(azColName[i], "name"))
+            gtk_list_store_set(list, &iter, 1, argv[i], -1);
+        if(!strcmp(azColName[i], "cid"))
+            gtk_list_store_set(list, &iter, 2, atoi(argv[i]), -1);
+        if(!strcmp(azColName[i], "region_id"))
+            gtk_list_store_set(list, &iter, 3, atoi(argv[i]), -1);
+
+    }
+#ifdef DEBUGFUNCTIONCALL
+    END_FUNCTION;
+#endif
+
+    return 0;
+}
+
+/*******************************************************************************/
+GtkListStore*
+get_all_information_about_station(gchar *source, gchar *station_code){
+
+    sqlite3    *database = NULL;
+    gchar buffer[2048];
+    gchar       *errMsg = NULL;
+    gchar       sql[1024];
+    gint        rc;
+    GtkListStore    *list = NULL;
+
+#ifdef DEBUGFUNCTIONCALL
+    START_FUNCTION;
+#endif
+
+    snprintf(buffer, sizeof(buffer) - 1, "%s.db",source);
+    database = open_database(DATABASEPATH, buffer);
+    if (!database)
+        return NULL;
+    list = gtk_list_store_new(4, G_TYPE_STRING, G_TYPE_STRING, G_TYPE_INT, G_TYPE_INT);
+    snprintf(sql, sizeof(sql) - 1, "Select countries.name as cname, regions.name, countries.id as cid, \
+                                    stations.region_id from stations,regions,countries \
+                                    where stations.code='%s' and stations.region_id=regions.id and \
+                                    regions.country_id=countries.id and countries.id=regions.country_id",
+                                    station_code);
+    rc = sqlite3_exec(database, sql, get_all_information_callback, (void*)list, &errMsg);
+    if(rc != SQLITE_OK){
+#ifndef RELEASE
+      fprintf(stderr, "\n>>>>%s\n", errMsg);
+#endif
+        sqlite3_free(errMsg);
+        return NULL;
+    }
+    close_database(database);
+    return list;
+}
+/*******************************************************************************/
+gint
+get_country_code(gchar *source, gchar *country_name){
+
+    sqlite3    *database = NULL;
+    gchar buffer[2048];
+    gchar       *errMsg = NULL;
+    gchar       sql[1024];
+    gint        rc;
+    GtkListStore    *list = NULL;
+    GtkTreeIter     iter;
+    gboolean valid;
+
+#ifdef DEBUGFUNCTIONCALL
+    START_FUNCTION;
+#endif
+
+    snprintf(buffer, sizeof(buffer) - 1, "%s.db",source);
+    database = open_database(DATABASEPATH, buffer);
+    if (!database)
+        return -1;
+    list = gtk_list_store_new(1, G_TYPE_INT);
+    snprintf(sql, sizeof(sql) - 1, "Select id from countries \
+                                    where name='%s'", country_name);
+    rc = sqlite3_exec(database, sql, get_country_code_callback, (void*)list, &errMsg);
+    if(rc != SQLITE_OK){
+#ifndef RELEASE
+      fprintf(stderr, "\n>>>>%s\n", errMsg);
+#endif
+        sqlite3_free(errMsg);
+        return -1;
+    }
+    close_database(database);
+    valid = gtk_tree_model_get_iter_first(GTK_TREE_MODEL
+                                      (list), &iter);
+    if (valid)
+      gtk_tree_model_get(GTK_TREE_MODEL(list),
+                           &iter,
+                           0, &rc,
+                          -1);
+#ifdef DEBUGFUNCTIONCALL
+    END_FUNCTION;
+#endif
+    return rc;
+}
+
+/*******************************************************************************/
+gint
+get_state_code(gchar *source, gchar *region_name){
+
+    sqlite3    *database = NULL;
+    gchar buffer[2048];
+    gchar       *errMsg = NULL;
+    gchar       sql[1024];
+    gint        rc;
+    GtkListStore    *list = NULL;
+    GtkTreeIter     iter;
+    gboolean valid;
+
+#ifdef DEBUGFUNCTIONCALL
+    START_FUNCTION;
+#endif
+
+    snprintf(buffer, sizeof(buffer) - 1, "%s.db",source);
+    database = open_database(DATABASEPATH, buffer);
+    if (!database)
+        return -1;
+    list = gtk_list_store_new(1, G_TYPE_INT);
+    snprintf(sql, sizeof(sql) - 1, "Select id from regions \
+                                    where name='%s'", region_name);
+    rc = sqlite3_exec(database, sql, get_state_code_callback, (void*)list, &errMsg);
+    if(rc != SQLITE_OK){
+#ifndef RELEASE
+      fprintf(stderr, "\n>>>>%s\n", errMsg);
+#endif
+        sqlite3_free(errMsg);
+        return -1;
+    }
+    close_database(database);
+    valid = gtk_tree_model_get_iter_first(GTK_TREE_MODEL
+                                      (list), &iter);
+    if (valid)
+      gtk_tree_model_get(GTK_TREE_MODEL(list),
+                           &iter,
+                           0, &rc,
+                          -1);
+#ifdef DEBUGFUNCTIONCALL
+    END_FUNCTION;
+#endif
+    return rc;
+}
+
+
+/*******************************************************************************/
+gchar*
+get_station_code(gchar *source, gint region_id, gchar *station_name){
+    sqlite3             *database = NULL;
+    gchar               buffer[2048],
+                        *errMsg = NULL,
+                        sql[1024];
+    gint                rc;
+    GtkListStore        *list = NULL;
+    GtkTreeIter         iter;
+    gboolean            valid;
+    gchar               *code;
+#ifdef DEBUGFUNCTIONCALL
+    START_FUNCTION;
+#endif
+    snprintf(buffer, sizeof(buffer) - 1, "%s.db",source);
+    database = open_database(DATABASEPATH, buffer);
+    if(!database)
+        return NULL;
+    list = gtk_list_store_new(1, G_TYPE_STRING);
+    /* Correct SQL */
+    snprintf(sql, sizeof(sql) - 1, "Select code from stations \
+                                    where name='%s' and region_id='%i'", station_name, region_id);
+    rc = sqlite3_exec(database, sql, get_station_code_callback, (void*)list, &errMsg);
+    if(rc != SQLITE_OK){
+#ifndef RELEASE
+      fprintf(stderr, "\n>>>>%s\n", errMsg);
+#endif
+        sqlite3_free(errMsg);
+        return NULL;
+    }
+    close_database(database);
+    valid = gtk_tree_model_get_iter_first(GTK_TREE_MODEL(list), &iter);
+    if(valid)
+        gtk_tree_model_get(GTK_TREE_MODEL(list), &iter, 0, &code, -1);
+#ifdef DEBUGFUNCTIONCALL
+    END_FUNCTION;
+#endif
+    return code;
+}
+/*******************************************************************************/
+GtkListStore* 
+search_station_in_database(sqlite3 *database, char *code_name){
     GtkListStore	*list = NULL;
     gint		rc;
     gchar		*errMsg = NULL;
-    gchar		sql[256];
+    gchar		sql[1024];
 
     if(!database || !code_name)
-	return NULL;
+        return NULL;
     *sql = 0;
 
     list = gtk_list_store_new(4, G_TYPE_STRING, G_TYPE_STRING, G_TYPE_STRING,
-				G_TYPE_STRING);
+              G_TYPE_STRING);
     snprintf(sql, sizeof(sql) - 1,
-	    "SELECT stations.name, sources.code, regions.name AS region_name, \
-	    countries.name AS country_name FROM stations JOIN sources,regions, \
-	    countries ON stations.id = sources.station_id AND stations.region_id \
-	    = regions.id AND regions.country_id = countries.id WHERE stations.name \
-	    LIKE('%s%%') OR sources.code LIKE('%s%%')",
-	    code_name, code_name);
+        "SELECT stations.name, sources.code, regions.name AS region_name, \
+        countries.name AS country_name FROM stations JOIN sources,regions, \
+        countries ON stations.id = sources.station_id AND stations.region_id \
+        = regions.id AND regions.country_id = countries.id WHERE stations.name \
+        LIKE('%s%%') OR sources.code LIKE('%s%%')",
+        code_name, code_name);
     rc = sqlite3_exec(database, sql, search_callback, (void*)list, &errMsg);
     if(rc != SQLITE_OK){
 #ifndef RELEASE
@@ -469,16 +674,84 @@ int countries_callback(void *user_data, int argc, char **argv, char **azColName)
     GtkTreeIter		iter;
     GtkListStore	*list = GTK_LIST_STORE(user_data);
 
+#ifdef DEBUGFUNCTIONCALL
+    START_FUNCTION;
+#endif
+
 /* add new item for each first element */
     gtk_list_store_append(list, &iter);
     for(i = 0; i < argc; i++){
-	if(!strcmp(azColName[i], "id"))
-	    gtk_list_store_set(list, &iter, 1, atoi(argv[i]), -1);
-	if(!strcmp(azColName[i], "name"))
-	    gtk_list_store_set(list, &iter, 0, argv[i], -1);
+        if(!strcmp(azColName[i], "id"))
+          gtk_list_store_set(list, &iter, 1, atoi(argv[i]), -1);
+        if(!strcmp(azColName[i], "name"))
+          gtk_list_store_set(list, &iter, 0, argv[i], -1);
     }
     return 0;
 }
+/*******************************************************************************/
+int get_country_code_callback(void *user_data, int argc, char **argv, char **azColName){
+    int			i;
+    GtkTreeIter		iter;
+    GtkListStore	*list = GTK_LIST_STORE(user_data);
+#ifdef DEBUGFUNCTIONCALL
+    START_FUNCTION;
+#endif
+
+/* add new item for each first element */
+    gtk_list_store_append(list, &iter);
+    for(i = 0; i < argc; i++){
+        if(!strcmp(azColName[i], "id"))
+            gtk_list_store_set(list, &iter, 0, atoi(argv[i]), -1);
+        fprintf(stderr,"azColName[i] %s %i",azColName[i],atoi(argv[i]));
+    }
+#ifdef DEBUGFUNCTIONCALL
+    END_FUNCTION;
+#endif
+    return 0;
+}
+/*******************************************************************************/
+int get_station_code_callback(void *user_data, int argc, char **argv, char **azColName){
+    int			i;
+    GtkTreeIter		iter;
+    GtkListStore	*list = GTK_LIST_STORE(user_data);
+#ifdef DEBUGFUNCTIONCALL
+    START_FUNCTION;
+#endif
+
+/* add new item for each first element */
+    gtk_list_store_append(list, &iter);
+    for(i = 0; i < argc; i++){
+        if(!strcmp(azColName[i], "code"))
+            gtk_list_store_set(list, &iter, 0, argv[i], -1);
+    }
+#ifdef DEBUGFUNCTIONCALL
+    END_FUNCTION;
+#endif
+    return 0;
+}
+
+/*******************************************************************************/
+int get_state_code_callback(void *user_data, int argc, char **argv, char **azColName){
+    int			i;
+    GtkTreeIter		iter;
+    GtkListStore	*list = GTK_LIST_STORE(user_data);
+#ifdef DEBUGFUNCTIONCALL
+    START_FUNCTION;
+#endif
+
+/* add new item for each first element */
+    gtk_list_store_append(list, &iter);
+    for(i = 0; i < argc; i++){
+        if(!strcmp(azColName[i], "id"))
+            gtk_list_store_set(list, &iter, 0, atoi(argv[i]), -1);
+        fprintf(stderr,"azColName[i] %s %i",azColName[i],atoi(argv[i]));
+    }
+#ifdef DEBUGFUNCTIONCALL
+    END_FUNCTION;
+#endif
+    return 0;
+}
+
 /*******************************************************************************/
 int regions_callback(void *user_data, int argc, char **argv, char **azColName){
     int			i;
